# Archivematica Tools

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Install

```sh
pip install matica_tools
```

## How to use

[See the documentation](api.html) for full details of the Archivematica
API Client.

```python
from dotenv import load_dotenv
import os
```

```python
load_dotenv(override=True)

dashboard_url = os.environ.get("DASHBOARD_URL")
dashboard_username = os.environ.get("DASHBOARD_USERNAME")
dashboard_api_key = os.environ.get("DASHBOARD_API_KEY")

storage_service_url = os.environ.get("STORAGE_SERVICE_URL")
storage_service_username = os.environ.get("STORAGE_SERVICE_USERNAME")
storage_service_password = os.environ.get("STORAGE_SERVICE_PASSWORD")
```

```python
client = ArchivematicaAPIClient(dashboard_url, dashboard_username, dashboard_api_key, storage_service_url, storage_service_username, storage_service_password)
```

```python
transfer_UUID = client.v2beta_package("standard", "", "bfe37714-61c2-432e-b375-af9253e114da", "/home/archivematica/archivematica-sampledata/SampleTransfers/DemoTransferCSV", "transfer v2 demo", "automated")
transfer_UUID
```

    '2d68be44-48f4-4b15-8db8-d8d1250f50bf'

See [the documentation](api.html) for more examples.

---

Created by [Satoru
Nakamura](https://researchmap.jp/nakamura.satoru?lang=en).
